# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import StrictInt, StrictStr

from typing import Optional


from prowlarr.api_client import ApiClient
from prowlarr.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class NewznabApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_indexerid_download(self, id : StrictInt, link : Optional[StrictStr] = None, file : Optional[StrictStr] = None, **kwargs) -> None:  # noqa: E501
        """get_indexerid_download  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_indexerid_download(id, link, file, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param link:
        :type link: str
        :param file:
        :type file: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.get_indexerid_download_with_http_info(id, link, file, **kwargs)  # noqa: E501

    @validate_arguments
    def get_indexerid_download_with_http_info(self, id : StrictInt, link : Optional[StrictStr] = None, file : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """get_indexerid_download  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_indexerid_download_with_http_info(id, link, file, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param link:
        :type link: str
        :param file:
        :type file: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id',
            'link',
            'file'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indexerid_download" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']

        # process the query parameters
        _query_params = []
        if _params.get('link') is not None:  # noqa: E501
            _query_params.append(('link', _params['link']))
        if _params.get('file') is not None:  # noqa: E501
            _query_params.append(('file', _params['file']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/indexer/{id}/download', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_indexerid_newznab(self, id : StrictInt, t : Optional[StrictStr] = None, q : Optional[StrictStr] = None, cat : Optional[StrictStr] = None, imdbid : Optional[StrictStr] = None, tmdbid : Optional[StrictInt] = None, extended : Optional[StrictStr] = None, limit : Optional[StrictInt] = None, offset : Optional[StrictInt] = None, rid : Optional[StrictInt] = None, tvmazeid : Optional[StrictInt] = None, traktid : Optional[StrictInt] = None, tvdbid : Optional[StrictInt] = None, doubanid : Optional[StrictInt] = None, season : Optional[StrictInt] = None, ep : Optional[StrictStr] = None, album : Optional[StrictStr] = None, artist : Optional[StrictStr] = None, label : Optional[StrictStr] = None, track : Optional[StrictStr] = None, year : Optional[StrictInt] = None, genre : Optional[StrictStr] = None, author : Optional[StrictStr] = None, title : Optional[StrictStr] = None, publisher : Optional[StrictStr] = None, configured : Optional[StrictStr] = None, source : Optional[StrictStr] = None, host : Optional[StrictStr] = None, server : Optional[StrictStr] = None, **kwargs) -> None:  # noqa: E501
        """get_indexerid_newznab  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_indexerid_newznab(id, t, q, cat, imdbid, tmdbid, extended, limit, offset, rid, tvmazeid, traktid, tvdbid, doubanid, season, ep, album, artist, label, track, year, genre, author, title, publisher, configured, source, host, server, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param t:
        :type t: str
        :param q:
        :type q: str
        :param cat:
        :type cat: str
        :param imdbid:
        :type imdbid: str
        :param tmdbid:
        :type tmdbid: int
        :param extended:
        :type extended: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param rid:
        :type rid: int
        :param tvmazeid:
        :type tvmazeid: int
        :param traktid:
        :type traktid: int
        :param tvdbid:
        :type tvdbid: int
        :param doubanid:
        :type doubanid: int
        :param season:
        :type season: int
        :param ep:
        :type ep: str
        :param album:
        :type album: str
        :param artist:
        :type artist: str
        :param label:
        :type label: str
        :param track:
        :type track: str
        :param year:
        :type year: int
        :param genre:
        :type genre: str
        :param author:
        :type author: str
        :param title:
        :type title: str
        :param publisher:
        :type publisher: str
        :param configured:
        :type configured: str
        :param source:
        :type source: str
        :param host:
        :type host: str
        :param server:
        :type server: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.get_indexerid_newznab_with_http_info(id, t, q, cat, imdbid, tmdbid, extended, limit, offset, rid, tvmazeid, traktid, tvdbid, doubanid, season, ep, album, artist, label, track, year, genre, author, title, publisher, configured, source, host, server, **kwargs)  # noqa: E501

    @validate_arguments
    def get_indexerid_newznab_with_http_info(self, id : StrictInt, t : Optional[StrictStr] = None, q : Optional[StrictStr] = None, cat : Optional[StrictStr] = None, imdbid : Optional[StrictStr] = None, tmdbid : Optional[StrictInt] = None, extended : Optional[StrictStr] = None, limit : Optional[StrictInt] = None, offset : Optional[StrictInt] = None, rid : Optional[StrictInt] = None, tvmazeid : Optional[StrictInt] = None, traktid : Optional[StrictInt] = None, tvdbid : Optional[StrictInt] = None, doubanid : Optional[StrictInt] = None, season : Optional[StrictInt] = None, ep : Optional[StrictStr] = None, album : Optional[StrictStr] = None, artist : Optional[StrictStr] = None, label : Optional[StrictStr] = None, track : Optional[StrictStr] = None, year : Optional[StrictInt] = None, genre : Optional[StrictStr] = None, author : Optional[StrictStr] = None, title : Optional[StrictStr] = None, publisher : Optional[StrictStr] = None, configured : Optional[StrictStr] = None, source : Optional[StrictStr] = None, host : Optional[StrictStr] = None, server : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """get_indexerid_newznab  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_indexerid_newznab_with_http_info(id, t, q, cat, imdbid, tmdbid, extended, limit, offset, rid, tvmazeid, traktid, tvdbid, doubanid, season, ep, album, artist, label, track, year, genre, author, title, publisher, configured, source, host, server, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param t:
        :type t: str
        :param q:
        :type q: str
        :param cat:
        :type cat: str
        :param imdbid:
        :type imdbid: str
        :param tmdbid:
        :type tmdbid: int
        :param extended:
        :type extended: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param rid:
        :type rid: int
        :param tvmazeid:
        :type tvmazeid: int
        :param traktid:
        :type traktid: int
        :param tvdbid:
        :type tvdbid: int
        :param doubanid:
        :type doubanid: int
        :param season:
        :type season: int
        :param ep:
        :type ep: str
        :param album:
        :type album: str
        :param artist:
        :type artist: str
        :param label:
        :type label: str
        :param track:
        :type track: str
        :param year:
        :type year: int
        :param genre:
        :type genre: str
        :param author:
        :type author: str
        :param title:
        :type title: str
        :param publisher:
        :type publisher: str
        :param configured:
        :type configured: str
        :param source:
        :type source: str
        :param host:
        :type host: str
        :param server:
        :type server: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id',
            't',
            'q',
            'cat',
            'imdbid',
            'tmdbid',
            'extended',
            'limit',
            'offset',
            'rid',
            'tvmazeid',
            'traktid',
            'tvdbid',
            'doubanid',
            'season',
            'ep',
            'album',
            'artist',
            'label',
            'track',
            'year',
            'genre',
            'author',
            'title',
            'publisher',
            'configured',
            'source',
            'host',
            'server'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_indexerid_newznab" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']

        # process the query parameters
        _query_params = []
        if _params.get('t') is not None:  # noqa: E501
            _query_params.append(('t', _params['t']))
        if _params.get('q') is not None:  # noqa: E501
            _query_params.append(('q', _params['q']))
        if _params.get('cat') is not None:  # noqa: E501
            _query_params.append(('cat', _params['cat']))
        if _params.get('imdbid') is not None:  # noqa: E501
            _query_params.append(('imdbid', _params['imdbid']))
        if _params.get('tmdbid') is not None:  # noqa: E501
            _query_params.append(('tmdbid', _params['tmdbid']))
        if _params.get('extended') is not None:  # noqa: E501
            _query_params.append(('extended', _params['extended']))
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))
        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))
        if _params.get('rid') is not None:  # noqa: E501
            _query_params.append(('rid', _params['rid']))
        if _params.get('tvmazeid') is not None:  # noqa: E501
            _query_params.append(('tvmazeid', _params['tvmazeid']))
        if _params.get('traktid') is not None:  # noqa: E501
            _query_params.append(('traktid', _params['traktid']))
        if _params.get('tvdbid') is not None:  # noqa: E501
            _query_params.append(('tvdbid', _params['tvdbid']))
        if _params.get('doubanid') is not None:  # noqa: E501
            _query_params.append(('doubanid', _params['doubanid']))
        if _params.get('season') is not None:  # noqa: E501
            _query_params.append(('season', _params['season']))
        if _params.get('ep') is not None:  # noqa: E501
            _query_params.append(('ep', _params['ep']))
        if _params.get('album') is not None:  # noqa: E501
            _query_params.append(('album', _params['album']))
        if _params.get('artist') is not None:  # noqa: E501
            _query_params.append(('artist', _params['artist']))
        if _params.get('label') is not None:  # noqa: E501
            _query_params.append(('label', _params['label']))
        if _params.get('track') is not None:  # noqa: E501
            _query_params.append(('track', _params['track']))
        if _params.get('year') is not None:  # noqa: E501
            _query_params.append(('year', _params['year']))
        if _params.get('genre') is not None:  # noqa: E501
            _query_params.append(('genre', _params['genre']))
        if _params.get('author') is not None:  # noqa: E501
            _query_params.append(('author', _params['author']))
        if _params.get('title') is not None:  # noqa: E501
            _query_params.append(('title', _params['title']))
        if _params.get('publisher') is not None:  # noqa: E501
            _query_params.append(('publisher', _params['publisher']))
        if _params.get('configured') is not None:  # noqa: E501
            _query_params.append(('configured', _params['configured']))
        if _params.get('source') is not None:  # noqa: E501
            _query_params.append(('source', _params['source']))
        if _params.get('host') is not None:  # noqa: E501
            _query_params.append(('host', _params['host']))
        if _params.get('server') is not None:  # noqa: E501
            _query_params.append(('server', _params['server']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/indexer/{id}/newznab', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def getid_api(self, id : StrictInt, t : Optional[StrictStr] = None, q : Optional[StrictStr] = None, cat : Optional[StrictStr] = None, imdbid : Optional[StrictStr] = None, tmdbid : Optional[StrictInt] = None, extended : Optional[StrictStr] = None, limit : Optional[StrictInt] = None, offset : Optional[StrictInt] = None, rid : Optional[StrictInt] = None, tvmazeid : Optional[StrictInt] = None, traktid : Optional[StrictInt] = None, tvdbid : Optional[StrictInt] = None, doubanid : Optional[StrictInt] = None, season : Optional[StrictInt] = None, ep : Optional[StrictStr] = None, album : Optional[StrictStr] = None, artist : Optional[StrictStr] = None, label : Optional[StrictStr] = None, track : Optional[StrictStr] = None, year : Optional[StrictInt] = None, genre : Optional[StrictStr] = None, author : Optional[StrictStr] = None, title : Optional[StrictStr] = None, publisher : Optional[StrictStr] = None, configured : Optional[StrictStr] = None, source : Optional[StrictStr] = None, host : Optional[StrictStr] = None, server : Optional[StrictStr] = None, **kwargs) -> None:  # noqa: E501
        """getid_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.getid_api(id, t, q, cat, imdbid, tmdbid, extended, limit, offset, rid, tvmazeid, traktid, tvdbid, doubanid, season, ep, album, artist, label, track, year, genre, author, title, publisher, configured, source, host, server, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param t:
        :type t: str
        :param q:
        :type q: str
        :param cat:
        :type cat: str
        :param imdbid:
        :type imdbid: str
        :param tmdbid:
        :type tmdbid: int
        :param extended:
        :type extended: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param rid:
        :type rid: int
        :param tvmazeid:
        :type tvmazeid: int
        :param traktid:
        :type traktid: int
        :param tvdbid:
        :type tvdbid: int
        :param doubanid:
        :type doubanid: int
        :param season:
        :type season: int
        :param ep:
        :type ep: str
        :param album:
        :type album: str
        :param artist:
        :type artist: str
        :param label:
        :type label: str
        :param track:
        :type track: str
        :param year:
        :type year: int
        :param genre:
        :type genre: str
        :param author:
        :type author: str
        :param title:
        :type title: str
        :param publisher:
        :type publisher: str
        :param configured:
        :type configured: str
        :param source:
        :type source: str
        :param host:
        :type host: str
        :param server:
        :type server: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.getid_api_with_http_info(id, t, q, cat, imdbid, tmdbid, extended, limit, offset, rid, tvmazeid, traktid, tvdbid, doubanid, season, ep, album, artist, label, track, year, genre, author, title, publisher, configured, source, host, server, **kwargs)  # noqa: E501

    @validate_arguments
    def getid_api_with_http_info(self, id : StrictInt, t : Optional[StrictStr] = None, q : Optional[StrictStr] = None, cat : Optional[StrictStr] = None, imdbid : Optional[StrictStr] = None, tmdbid : Optional[StrictInt] = None, extended : Optional[StrictStr] = None, limit : Optional[StrictInt] = None, offset : Optional[StrictInt] = None, rid : Optional[StrictInt] = None, tvmazeid : Optional[StrictInt] = None, traktid : Optional[StrictInt] = None, tvdbid : Optional[StrictInt] = None, doubanid : Optional[StrictInt] = None, season : Optional[StrictInt] = None, ep : Optional[StrictStr] = None, album : Optional[StrictStr] = None, artist : Optional[StrictStr] = None, label : Optional[StrictStr] = None, track : Optional[StrictStr] = None, year : Optional[StrictInt] = None, genre : Optional[StrictStr] = None, author : Optional[StrictStr] = None, title : Optional[StrictStr] = None, publisher : Optional[StrictStr] = None, configured : Optional[StrictStr] = None, source : Optional[StrictStr] = None, host : Optional[StrictStr] = None, server : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """getid_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.getid_api_with_http_info(id, t, q, cat, imdbid, tmdbid, extended, limit, offset, rid, tvmazeid, traktid, tvdbid, doubanid, season, ep, album, artist, label, track, year, genre, author, title, publisher, configured, source, host, server, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param t:
        :type t: str
        :param q:
        :type q: str
        :param cat:
        :type cat: str
        :param imdbid:
        :type imdbid: str
        :param tmdbid:
        :type tmdbid: int
        :param extended:
        :type extended: str
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param rid:
        :type rid: int
        :param tvmazeid:
        :type tvmazeid: int
        :param traktid:
        :type traktid: int
        :param tvdbid:
        :type tvdbid: int
        :param doubanid:
        :type doubanid: int
        :param season:
        :type season: int
        :param ep:
        :type ep: str
        :param album:
        :type album: str
        :param artist:
        :type artist: str
        :param label:
        :type label: str
        :param track:
        :type track: str
        :param year:
        :type year: int
        :param genre:
        :type genre: str
        :param author:
        :type author: str
        :param title:
        :type title: str
        :param publisher:
        :type publisher: str
        :param configured:
        :type configured: str
        :param source:
        :type source: str
        :param host:
        :type host: str
        :param server:
        :type server: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id',
            't',
            'q',
            'cat',
            'imdbid',
            'tmdbid',
            'extended',
            'limit',
            'offset',
            'rid',
            'tvmazeid',
            'traktid',
            'tvdbid',
            'doubanid',
            'season',
            'ep',
            'album',
            'artist',
            'label',
            'track',
            'year',
            'genre',
            'author',
            'title',
            'publisher',
            'configured',
            'source',
            'host',
            'server'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method getid_api" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']

        # process the query parameters
        _query_params = []
        if _params.get('t') is not None:  # noqa: E501
            _query_params.append(('t', _params['t']))
        if _params.get('q') is not None:  # noqa: E501
            _query_params.append(('q', _params['q']))
        if _params.get('cat') is not None:  # noqa: E501
            _query_params.append(('cat', _params['cat']))
        if _params.get('imdbid') is not None:  # noqa: E501
            _query_params.append(('imdbid', _params['imdbid']))
        if _params.get('tmdbid') is not None:  # noqa: E501
            _query_params.append(('tmdbid', _params['tmdbid']))
        if _params.get('extended') is not None:  # noqa: E501
            _query_params.append(('extended', _params['extended']))
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))
        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))
        if _params.get('rid') is not None:  # noqa: E501
            _query_params.append(('rid', _params['rid']))
        if _params.get('tvmazeid') is not None:  # noqa: E501
            _query_params.append(('tvmazeid', _params['tvmazeid']))
        if _params.get('traktid') is not None:  # noqa: E501
            _query_params.append(('traktid', _params['traktid']))
        if _params.get('tvdbid') is not None:  # noqa: E501
            _query_params.append(('tvdbid', _params['tvdbid']))
        if _params.get('doubanid') is not None:  # noqa: E501
            _query_params.append(('doubanid', _params['doubanid']))
        if _params.get('season') is not None:  # noqa: E501
            _query_params.append(('season', _params['season']))
        if _params.get('ep') is not None:  # noqa: E501
            _query_params.append(('ep', _params['ep']))
        if _params.get('album') is not None:  # noqa: E501
            _query_params.append(('album', _params['album']))
        if _params.get('artist') is not None:  # noqa: E501
            _query_params.append(('artist', _params['artist']))
        if _params.get('label') is not None:  # noqa: E501
            _query_params.append(('label', _params['label']))
        if _params.get('track') is not None:  # noqa: E501
            _query_params.append(('track', _params['track']))
        if _params.get('year') is not None:  # noqa: E501
            _query_params.append(('year', _params['year']))
        if _params.get('genre') is not None:  # noqa: E501
            _query_params.append(('genre', _params['genre']))
        if _params.get('author') is not None:  # noqa: E501
            _query_params.append(('author', _params['author']))
        if _params.get('title') is not None:  # noqa: E501
            _query_params.append(('title', _params['title']))
        if _params.get('publisher') is not None:  # noqa: E501
            _query_params.append(('publisher', _params['publisher']))
        if _params.get('configured') is not None:  # noqa: E501
            _query_params.append(('configured', _params['configured']))
        if _params.get('source') is not None:  # noqa: E501
            _query_params.append(('source', _params['source']))
        if _params.get('host') is not None:  # noqa: E501
            _query_params.append(('host', _params['host']))
        if _params.get('server') is not None:  # noqa: E501
            _query_params.append(('server', _params['server']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/{id}/api', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def getid_download(self, id : StrictInt, link : Optional[StrictStr] = None, file : Optional[StrictStr] = None, **kwargs) -> None:  # noqa: E501
        """getid_download  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.getid_download(id, link, file, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param link:
        :type link: str
        :param file:
        :type file: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.getid_download_with_http_info(id, link, file, **kwargs)  # noqa: E501

    @validate_arguments
    def getid_download_with_http_info(self, id : StrictInt, link : Optional[StrictStr] = None, file : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """getid_download  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.getid_download_with_http_info(id, link, file, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param link:
        :type link: str
        :param file:
        :type file: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id',
            'link',
            'file'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method getid_download" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']

        # process the query parameters
        _query_params = []
        if _params.get('link') is not None:  # noqa: E501
            _query_params.append(('link', _params['link']))
        if _params.get('file') is not None:  # noqa: E501
            _query_params.append(('file', _params['file']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/{id}/download', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel

class UiConfigResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    first_day_of_week: Optional[int]
    calendar_week_column_header: Optional[str]
    short_date_format: Optional[str]
    long_date_format: Optional[str]
    time_format: Optional[str]
    show_relative_dates: Optional[bool]
    enable_color_impaired_mode: Optional[bool]
    ui_language: Optional[str]
    theme: Optional[str]
    __properties = ["id", "firstDayOfWeek", "calendarWeekColumnHeader", "shortDateFormat", "longDateFormat", "timeFormat", "showRelativeDates", "enableColorImpairedMode", "uiLanguage", "theme"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UiConfigResource:
        """Create an instance of UiConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if calendar_week_column_header (nullable) is None
        if self.calendar_week_column_header is None:
            _dict['calendarWeekColumnHeader'] = None

        # set to None if short_date_format (nullable) is None
        if self.short_date_format is None:
            _dict['shortDateFormat'] = None

        # set to None if long_date_format (nullable) is None
        if self.long_date_format is None:
            _dict['longDateFormat'] = None

        # set to None if time_format (nullable) is None
        if self.time_format is None:
            _dict['timeFormat'] = None

        # set to None if ui_language (nullable) is None
        if self.ui_language is None:
            _dict['uiLanguage'] = None

        # set to None if theme (nullable) is None
        if self.theme is None:
            _dict['theme'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UiConfigResource:
        """Create an instance of UiConfigResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return UiConfigResource.parse_obj(obj)

        _obj = UiConfigResource.parse_obj({
            "id": obj.get("id"),
            "first_day_of_week": obj.get("firstDayOfWeek"),
            "calendar_week_column_header": obj.get("calendarWeekColumnHeader"),
            "short_date_format": obj.get("shortDateFormat"),
            "long_date_format": obj.get("longDateFormat"),
            "time_format": obj.get("timeFormat"),
            "show_relative_dates": obj.get("showRelativeDates"),
            "enable_color_impaired_mode": obj.get("enableColorImpairedMode"),
            "ui_language": obj.get("uiLanguage"),
            "theme": obj.get("theme")
        })
        return _obj




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel
from prowlarr.models.update_changes import UpdateChanges

class UpdateResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    version: Optional[str]
    branch: Optional[str]
    release_date: Optional[datetime]
    file_name: Optional[str]
    url: Optional[str]
    installed: Optional[bool]
    installed_on: Optional[datetime]
    installable: Optional[bool]
    latest: Optional[bool]
    changes: Optional[UpdateChanges]
    hash: Optional[str]
    __properties = ["id", "version", "branch", "releaseDate", "fileName", "url", "installed", "installedOn", "installable", "latest", "changes", "hash"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateResource:
        """Create an instance of UpdateResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of changes
        if self.changes:
            _dict['changes'] = self.changes.to_dict()
        # set to None if branch (nullable) is None
        if self.branch is None:
            _dict['branch'] = None

        # set to None if file_name (nullable) is None
        if self.file_name is None:
            _dict['fileName'] = None

        # set to None if url (nullable) is None
        if self.url is None:
            _dict['url'] = None

        # set to None if installed_on (nullable) is None
        if self.installed_on is None:
            _dict['installedOn'] = None

        # set to None if hash (nullable) is None
        if self.hash is None:
            _dict['hash'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateResource:
        """Create an instance of UpdateResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return UpdateResource.parse_obj(obj)

        _obj = UpdateResource.parse_obj({
            "id": obj.get("id"),
            "version": obj.get("version"),
            "branch": obj.get("branch"),
            "release_date": obj.get("releaseDate"),
            "file_name": obj.get("fileName"),
            "url": obj.get("url"),
            "installed": obj.get("installed"),
            "installed_on": obj.get("installedOn"),
            "installable": obj.get("installable"),
            "latest": obj.get("latest"),
            "changes": UpdateChanges.from_dict(obj.get("changes")) if obj.get("changes") is not None else None,
            "hash": obj.get("hash")
        })
        return _obj




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel
from prowlarr.models.command_trigger import CommandTrigger

class Command(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    send_updates_to_client: Optional[bool]
    update_scheduled_task: Optional[bool]
    completion_message: Optional[str]
    requires_disk_access: Optional[bool]
    is_exclusive: Optional[bool]
    is_type_exclusive: Optional[bool]
    name: Optional[str]
    last_execution_time: Optional[datetime]
    last_start_time: Optional[datetime]
    trigger: Optional[CommandTrigger]
    suppress_messages: Optional[bool]
    client_user_agent: Optional[str]
    __properties = ["sendUpdatesToClient", "updateScheduledTask", "completionMessage", "requiresDiskAccess", "isExclusive", "isTypeExclusive", "name", "lastExecutionTime", "lastStartTime", "trigger", "suppressMessages", "clientUserAgent"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Command:
        """Create an instance of Command from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "update_scheduled_task",
                            "completion_message",
                            "requires_disk_access",
                            "is_exclusive",
                            "is_type_exclusive",
                            "name",
                          },
                          exclude_none=True)
        # set to None if completion_message (nullable) is None
        if self.completion_message is None:
            _dict['completionMessage'] = None

        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if last_execution_time (nullable) is None
        if self.last_execution_time is None:
            _dict['lastExecutionTime'] = None

        # set to None if last_start_time (nullable) is None
        if self.last_start_time is None:
            _dict['lastStartTime'] = None

        # set to None if client_user_agent (nullable) is None
        if self.client_user_agent is None:
            _dict['clientUserAgent'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Command:
        """Create an instance of Command from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Command.parse_obj(obj)

        _obj = Command.parse_obj({
            "send_updates_to_client": obj.get("sendUpdatesToClient"),
            "update_scheduled_task": obj.get("updateScheduledTask"),
            "completion_message": obj.get("completionMessage"),
            "requires_disk_access": obj.get("requiresDiskAccess"),
            "is_exclusive": obj.get("isExclusive"),
            "is_type_exclusive": obj.get("isTypeExclusive"),
            "name": obj.get("name"),
            "last_execution_time": obj.get("lastExecutionTime"),
            "last_start_time": obj.get("lastStartTime"),
            "trigger": obj.get("trigger"),
            "suppress_messages": obj.get("suppressMessages"),
            "client_user_agent": obj.get("clientUserAgent")
        })
        return _obj




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from prowlarr.models.authentication_required_type import AuthenticationRequiredType
from prowlarr.models.authentication_type import AuthenticationType
from prowlarr.models.certificate_validation_type import CertificateValidationType
from prowlarr.models.proxy_type import ProxyType
from prowlarr.models.update_mechanism import UpdateMechanism

class HostConfigResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    bind_address: Optional[str]
    port: Optional[int]
    ssl_port: Optional[int]
    enable_ssl: Optional[bool]
    launch_browser: Optional[bool]
    authentication_method: Optional[AuthenticationType]
    authentication_required: Optional[AuthenticationRequiredType]
    analytics_enabled: Optional[bool]
    username: Optional[str]
    password: Optional[str]
    log_level: Optional[str]
    console_log_level: Optional[str]
    branch: Optional[str]
    api_key: Optional[str]
    ssl_cert_path: Optional[str]
    ssl_cert_password: Optional[str]
    url_base: Optional[str]
    instance_name: Optional[str]
    update_automatically: Optional[bool]
    update_mechanism: Optional[UpdateMechanism]
    update_script_path: Optional[str]
    proxy_enabled: Optional[bool]
    proxy_type: Optional[ProxyType]
    proxy_hostname: Optional[str]
    proxy_port: Optional[int]
    proxy_username: Optional[str]
    proxy_password: Optional[str]
    proxy_bypass_filter: Optional[str]
    proxy_bypass_local_addresses: Optional[bool]
    certificate_validation: Optional[CertificateValidationType]
    backup_folder: Optional[str]
    backup_interval: Optional[int]
    backup_retention: Optional[int]
    history_cleanup_days: Optional[int]
    __properties = ["id", "bindAddress", "port", "sslPort", "enableSsl", "launchBrowser", "authenticationMethod", "authenticationRequired", "analyticsEnabled", "username", "password", "logLevel", "consoleLogLevel", "branch", "apiKey", "sslCertPath", "sslCertPassword", "urlBase", "instanceName", "updateAutomatically", "updateMechanism", "updateScriptPath", "proxyEnabled", "proxyType", "proxyHostname", "proxyPort", "proxyUsername", "proxyPassword", "proxyBypassFilter", "proxyBypassLocalAddresses", "certificateValidation", "backupFolder", "backupInterval", "backupRetention", "historyCleanupDays"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> HostConfigResource:
        """Create an instance of HostConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if bind_address (nullable) is None
        if self.bind_address is None:
            _dict['bindAddress'] = None

        # set to None if username (nullable) is None
        if self.username is None:
            _dict['username'] = None

        # set to None if password (nullable) is None
        if self.password is None:
            _dict['password'] = None

        # set to None if log_level (nullable) is None
        if self.log_level is None:
            _dict['logLevel'] = None

        # set to None if console_log_level (nullable) is None
        if self.console_log_level is None:
            _dict['consoleLogLevel'] = None

        # set to None if branch (nullable) is None
        if self.branch is None:
            _dict['branch'] = None

        # set to None if api_key (nullable) is None
        if self.api_key is None:
            _dict['apiKey'] = None

        # set to None if ssl_cert_path (nullable) is None
        if self.ssl_cert_path is None:
            _dict['sslCertPath'] = None

        # set to None if ssl_cert_password (nullable) is None
        if self.ssl_cert_password is None:
            _dict['sslCertPassword'] = None

        # set to None if url_base (nullable) is None
        if self.url_base is None:
            _dict['urlBase'] = None

        # set to None if instance_name (nullable) is None
        if self.instance_name is None:
            _dict['instanceName'] = None

        # set to None if update_script_path (nullable) is None
        if self.update_script_path is None:
            _dict['updateScriptPath'] = None

        # set to None if proxy_hostname (nullable) is None
        if self.proxy_hostname is None:
            _dict['proxyHostname'] = None

        # set to None if proxy_username (nullable) is None
        if self.proxy_username is None:
            _dict['proxyUsername'] = None

        # set to None if proxy_password (nullable) is None
        if self.proxy_password is None:
            _dict['proxyPassword'] = None

        # set to None if proxy_bypass_filter (nullable) is None
        if self.proxy_bypass_filter is None:
            _dict['proxyBypassFilter'] = None

        # set to None if backup_folder (nullable) is None
        if self.backup_folder is None:
            _dict['backupFolder'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> HostConfigResource:
        """Create an instance of HostConfigResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return HostConfigResource.parse_obj(obj)

        _obj = HostConfigResource.parse_obj({
            "id": obj.get("id"),
            "bind_address": obj.get("bindAddress"),
            "port": obj.get("port"),
            "ssl_port": obj.get("sslPort"),
            "enable_ssl": obj.get("enableSsl"),
            "launch_browser": obj.get("launchBrowser"),
            "authentication_method": obj.get("authenticationMethod"),
            "authentication_required": obj.get("authenticationRequired"),
            "analytics_enabled": obj.get("analyticsEnabled"),
            "username": obj.get("username"),
            "password": obj.get("password"),
            "log_level": obj.get("logLevel"),
            "console_log_level": obj.get("consoleLogLevel"),
            "branch": obj.get("branch"),
            "api_key": obj.get("apiKey"),
            "ssl_cert_path": obj.get("sslCertPath"),
            "ssl_cert_password": obj.get("sslCertPassword"),
            "url_base": obj.get("urlBase"),
            "instance_name": obj.get("instanceName"),
            "update_automatically": obj.get("updateAutomatically"),
            "update_mechanism": obj.get("updateMechanism"),
            "update_script_path": obj.get("updateScriptPath"),
            "proxy_enabled": obj.get("proxyEnabled"),
            "proxy_type": obj.get("proxyType"),
            "proxy_hostname": obj.get("proxyHostname"),
            "proxy_port": obj.get("proxyPort"),
            "proxy_username": obj.get("proxyUsername"),
            "proxy_password": obj.get("proxyPassword"),
            "proxy_bypass_filter": obj.get("proxyBypassFilter"),
            "proxy_bypass_local_addresses": obj.get("proxyBypassLocalAddresses"),
            "certificate_validation": obj.get("certificateValidation"),
            "backup_folder": obj.get("backupFolder"),
            "backup_interval": obj.get("backupInterval"),
            "backup_retention": obj.get("backupRetention"),
            "history_cleanup_days": obj.get("historyCleanupDays")
        })
        return _obj




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel

class LogResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    time: Optional[datetime]
    exception: Optional[str]
    exception_type: Optional[str]
    level: Optional[str]
    logger: Optional[str]
    message: Optional[str]
    method: Optional[str]
    __properties = ["id", "time", "exception", "exceptionType", "level", "logger", "message", "method"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LogResource:
        """Create an instance of LogResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if exception (nullable) is None
        if self.exception is None:
            _dict['exception'] = None

        # set to None if exception_type (nullable) is None
        if self.exception_type is None:
            _dict['exceptionType'] = None

        # set to None if level (nullable) is None
        if self.level is None:
            _dict['level'] = None

        # set to None if logger (nullable) is None
        if self.logger is None:
            _dict['logger'] = None

        # set to None if message (nullable) is None
        if self.message is None:
            _dict['message'] = None

        # set to None if method (nullable) is None
        if self.method is None:
            _dict['method'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LogResource:
        """Create an instance of LogResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return LogResource.parse_obj(obj)

        _obj = LogResource.parse_obj({
            "id": obj.get("id"),
            "time": obj.get("time"),
            "exception": obj.get("exception"),
            "exception_type": obj.get("exceptionType"),
            "level": obj.get("level"),
            "logger": obj.get("logger"),
            "message": obj.get("message"),
            "method": obj.get("method")
        })
        return _obj




# coding: utf-8

# flake8: noqa

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.0.1"

# import apis into sdk package
from prowlarr.api.api_info_api import ApiInfoApi
from prowlarr.api.app_profile_api import AppProfileApi
from prowlarr.api.application_api import ApplicationApi
from prowlarr.api.authentication_api import AuthenticationApi
from prowlarr.api.backup_api import BackupApi
from prowlarr.api.command_api import CommandApi
from prowlarr.api.custom_filter_api import CustomFilterApi
from prowlarr.api.development_config_api import DevelopmentConfigApi
from prowlarr.api.download_client_api import DownloadClientApi
from prowlarr.api.download_client_config_api import DownloadClientConfigApi
from prowlarr.api.file_system_api import FileSystemApi
from prowlarr.api.health_api import HealthApi
from prowlarr.api.history_api import HistoryApi
from prowlarr.api.host_config_api import HostConfigApi
from prowlarr.api.indexer_api import IndexerApi
from prowlarr.api.indexer_default_categories_api import IndexerDefaultCategoriesApi
from prowlarr.api.indexer_editor_api import IndexerEditorApi
from prowlarr.api.indexer_proxy_api import IndexerProxyApi
from prowlarr.api.indexer_stats_api import IndexerStatsApi
from prowlarr.api.indexer_status_api import IndexerStatusApi
from prowlarr.api.initialize_js_api import InitializeJsApi
from prowlarr.api.localization_api import LocalizationApi
from prowlarr.api.log_api import LogApi
from prowlarr.api.log_file_api import LogFileApi
from prowlarr.api.newznab_api import NewznabApi
from prowlarr.api.notification_api import NotificationApi
from prowlarr.api.ping_api import PingApi
from prowlarr.api.quality_profile_schema_api import QualityProfileSchemaApi
from prowlarr.api.search_api import SearchApi
from prowlarr.api.static_resource_api import StaticResourceApi
from prowlarr.api.system_api import SystemApi
from prowlarr.api.tag_api import TagApi
from prowlarr.api.tag_details_api import TagDetailsApi
from prowlarr.api.task_api import TaskApi
from prowlarr.api.ui_config_api import UiConfigApi
from prowlarr.api.update_api import UpdateApi
from prowlarr.api.update_log_file_api import UpdateLogFileApi

# import ApiClient
from prowlarr.api_client import ApiClient
from prowlarr.configuration import Configuration
from prowlarr.exceptions import OpenApiException
from prowlarr.exceptions import ApiTypeError
from prowlarr.exceptions import ApiValueError
from prowlarr.exceptions import ApiKeyError
from prowlarr.exceptions import ApiAttributeError
from prowlarr.exceptions import ApiException
# import models into sdk package
from prowlarr.models.api_info_resource import ApiInfoResource
from prowlarr.models.app_profile_resource import AppProfileResource
from prowlarr.models.application_resource import ApplicationResource
from prowlarr.models.application_sync_level import ApplicationSyncLevel
from prowlarr.models.apply_tags import ApplyTags
from prowlarr.models.authentication_required_type import AuthenticationRequiredType
from prowlarr.models.authentication_type import AuthenticationType
from prowlarr.models.backup_resource import BackupResource
from prowlarr.models.backup_type import BackupType
from prowlarr.models.book_search_param import BookSearchParam
from prowlarr.models.certificate_validation_type import CertificateValidationType
from prowlarr.models.command import Command
from prowlarr.models.command_priority import CommandPriority
from prowlarr.models.command_resource import CommandResource
from prowlarr.models.command_status import CommandStatus
from prowlarr.models.command_trigger import CommandTrigger
from prowlarr.models.custom_filter_resource import CustomFilterResource
from prowlarr.models.database_type import DatabaseType
from prowlarr.models.development_config_resource import DevelopmentConfigResource
from prowlarr.models.download_client_category import DownloadClientCategory
from prowlarr.models.download_client_config_resource import DownloadClientConfigResource
from prowlarr.models.download_client_resource import DownloadClientResource
from prowlarr.models.download_protocol import DownloadProtocol
from prowlarr.models.field import Field
from prowlarr.models.health_check_result import HealthCheckResult
from prowlarr.models.health_resource import HealthResource
from prowlarr.models.history_event_type import HistoryEventType
from prowlarr.models.history_resource import HistoryResource
from prowlarr.models.history_resource_paging_resource import HistoryResourcePagingResource
from prowlarr.models.host_config_resource import HostConfigResource
from prowlarr.models.host_statistics import HostStatistics
from prowlarr.models.http_uri import HttpUri
from prowlarr.models.indexer_capability_resource import IndexerCapabilityResource
from prowlarr.models.indexer_category import IndexerCategory
from prowlarr.models.indexer_editor_resource import IndexerEditorResource
from prowlarr.models.indexer_privacy import IndexerPrivacy
from prowlarr.models.indexer_proxy_resource import IndexerProxyResource
from prowlarr.models.indexer_resource import IndexerResource
from prowlarr.models.indexer_statistics import IndexerStatistics
from prowlarr.models.indexer_stats_resource import IndexerStatsResource
from prowlarr.models.indexer_status_resource import IndexerStatusResource
from prowlarr.models.localization_option import LocalizationOption
from prowlarr.models.log_file_resource import LogFileResource
from prowlarr.models.log_resource import LogResource
from prowlarr.models.log_resource_paging_resource import LogResourcePagingResource
from prowlarr.models.movie_search_param import MovieSearchParam
from prowlarr.models.music_search_param import MusicSearchParam
from prowlarr.models.notification_resource import NotificationResource
from prowlarr.models.paging_resource_filter import PagingResourceFilter
from prowlarr.models.ping_resource import PingResource
from prowlarr.models.provider_message import ProviderMessage
from prowlarr.models.provider_message_type import ProviderMessageType
from prowlarr.models.proxy_type import ProxyType
from prowlarr.models.release_resource import ReleaseResource
from prowlarr.models.runtime_mode import RuntimeMode
from prowlarr.models.search_param import SearchParam
from prowlarr.models.select_option import SelectOption
from prowlarr.models.sort_direction import SortDirection
from prowlarr.models.system_resource import SystemResource
from prowlarr.models.tag_details_resource import TagDetailsResource
from prowlarr.models.tag_resource import TagResource
from prowlarr.models.task_resource import TaskResource
from prowlarr.models.time_span import TimeSpan
from prowlarr.models.tv_search_param import TvSearchParam
from prowlarr.models.ui_config_resource import UiConfigResource
from prowlarr.models.update_changes import UpdateChanges
from prowlarr.models.update_mechanism import UpdateMechanism
from prowlarr.models.update_resource import UpdateResource
from prowlarr.models.user_agent_statistics import UserAgentStatistics
from prowlarr.models.version import Version



# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel
from prowlarr.models.command import Command
from prowlarr.models.command_priority import CommandPriority
from prowlarr.models.command_status import CommandStatus
from prowlarr.models.command_trigger import CommandTrigger
from prowlarr.models.time_span import TimeSpan

class CommandResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    name: Optional[str]
    command_name: Optional[str]
    message: Optional[str]
    body: Optional[Command]
    priority: Optional[CommandPriority]
    status: Optional[CommandStatus]
    queued: Optional[datetime]
    started: Optional[datetime]
    ended: Optional[datetime]
    duration: Optional[TimeSpan]
    exception: Optional[str]
    trigger: Optional[CommandTrigger]
    client_user_agent: Optional[str]
    state_change_time: Optional[datetime]
    send_updates_to_client: Optional[bool]
    update_scheduled_task: Optional[bool]
    last_execution_time: Optional[datetime]
    __properties = ["id", "name", "commandName", "message", "body", "priority", "status", "queued", "started", "ended", "duration", "exception", "trigger", "clientUserAgent", "stateChangeTime", "sendUpdatesToClient", "updateScheduledTask", "lastExecutionTime"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CommandResource:
        """Create an instance of CommandResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of body
        if self.body:
            _dict['body'] = self.body.to_dict()
        # override the default output from pydantic by calling `to_dict()` of duration
        if self.duration:
            _dict['duration'] = self.duration.to_dict()
        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if command_name (nullable) is None
        if self.command_name is None:
            _dict['commandName'] = None

        # set to None if message (nullable) is None
        if self.message is None:
            _dict['message'] = None

        # set to None if started (nullable) is None
        if self.started is None:
            _dict['started'] = None

        # set to None if ended (nullable) is None
        if self.ended is None:
            _dict['ended'] = None

        # set to None if exception (nullable) is None
        if self.exception is None:
            _dict['exception'] = None

        # set to None if client_user_agent (nullable) is None
        if self.client_user_agent is None:
            _dict['clientUserAgent'] = None

        # set to None if state_change_time (nullable) is None
        if self.state_change_time is None:
            _dict['stateChangeTime'] = None

        # set to None if last_execution_time (nullable) is None
        if self.last_execution_time is None:
            _dict['lastExecutionTime'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CommandResource:
        """Create an instance of CommandResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CommandResource.parse_obj(obj)

        _obj = CommandResource.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "command_name": obj.get("commandName"),
            "message": obj.get("message"),
            "body": Command.from_dict(obj.get("body")) if obj.get("body") is not None else None,
            "priority": obj.get("priority"),
            "status": obj.get("status"),
            "queued": obj.get("queued"),
            "started": obj.get("started"),
            "ended": obj.get("ended"),
            "duration": TimeSpan.from_dict(obj.get("duration")) if obj.get("duration") is not None else None,
            "exception": obj.get("exception"),
            "trigger": obj.get("trigger"),
            "client_user_agent": obj.get("clientUserAgent"),
            "state_change_time": obj.get("stateChangeTime"),
            "send_updates_to_client": obj.get("sendUpdatesToClient"),
            "update_scheduled_task": obj.get("updateScheduledTask"),
            "last_execution_time": obj.get("lastExecutionTime")
        })
        return _obj




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CommandStatus(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    QUEUED = 'queued'
    STARTED = 'started'
    COMPLETED = 'completed'
    FAILED = 'failed'
    ABORTED = 'aborted'
    CANCELLED = 'cancelled'
    ORPHANED = 'orphaned'




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import StrictInt, StrictStr

from typing import List, Optional

from prowlarr.models.release_resource import ReleaseResource

from prowlarr.api_client import ApiClient
from prowlarr.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SearchApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_search(self, release_resource : Optional[ReleaseResource] = None, **kwargs) -> ReleaseResource:  # noqa: E501
        """create_search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_search(release_resource, async_req=True)
        >>> result = thread.get()

        :param release_resource:
        :type release_resource: ReleaseResource
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ReleaseResource
        """
        kwargs['_return_http_data_only'] = True
        return self.create_search_with_http_info(release_resource, **kwargs)  # noqa: E501

    @validate_arguments
    def create_search_with_http_info(self, release_resource : Optional[ReleaseResource] = None, **kwargs):  # noqa: E501
        """create_search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_search_with_http_info(release_resource, async_req=True)
        >>> result = thread.get()

        :param release_resource:
        :type release_resource: ReleaseResource
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ReleaseResource, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'release_resource'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_search" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['release_resource']:
            _body_params = _params['release_resource']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'text/json', 'application/*+json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {
            '200': "ReleaseResource",
        }

        return self.api_client.call_api(
            '/api/v1/search', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_search_bulk(self, release_resource : Optional[List[ReleaseResource]] = None, **kwargs) -> ReleaseResource:  # noqa: E501
        """create_search_bulk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_search_bulk(release_resource, async_req=True)
        >>> result = thread.get()

        :param release_resource:
        :type release_resource: List[ReleaseResource]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ReleaseResource
        """
        kwargs['_return_http_data_only'] = True
        return self.create_search_bulk_with_http_info(release_resource, **kwargs)  # noqa: E501

    @validate_arguments
    def create_search_bulk_with_http_info(self, release_resource : Optional[List[ReleaseResource]] = None, **kwargs):  # noqa: E501
        """create_search_bulk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_search_bulk_with_http_info(release_resource, async_req=True)
        >>> result = thread.get()

        :param release_resource:
        :type release_resource: List[ReleaseResource]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ReleaseResource, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'release_resource'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_search_bulk" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['release_resource']:
            _body_params = _params['release_resource']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'text/json', 'application/*+json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {
            '200': "ReleaseResource",
        }

        return self.api_client.call_api(
            '/api/v1/search/bulk', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_search_by_id(self, id : StrictInt, **kwargs) -> ReleaseResource:  # noqa: E501
        """get_search_by_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_search_by_id(id, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ReleaseResource
        """
        kwargs['_return_http_data_only'] = True
        return self.get_search_by_id_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_search_by_id_with_http_info(self, id : StrictInt, **kwargs):  # noqa: E501
        """get_search_by_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_search_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ReleaseResource, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_search_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {
            '200': "ReleaseResource",
        }

        return self.api_client.call_api(
            '/api/v1/search/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_search(self, query : Optional[StrictStr] = None, type : Optional[StrictStr] = None, indexer_ids : Optional[List[StrictInt]] = None, categories : Optional[List[StrictInt]] = None, limit : Optional[StrictInt] = None, offset : Optional[StrictInt] = None, **kwargs) -> List[ReleaseResource]:  # noqa: E501
        """list_search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_search(query, type, indexer_ids, categories, limit, offset, async_req=True)
        >>> result = thread.get()

        :param query:
        :type query: str
        :param type:
        :type type: str
        :param indexer_ids:
        :type indexer_ids: List[int]
        :param categories:
        :type categories: List[int]
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[ReleaseResource]
        """
        kwargs['_return_http_data_only'] = True
        return self.list_search_with_http_info(query, type, indexer_ids, categories, limit, offset, **kwargs)  # noqa: E501

    @validate_arguments
    def list_search_with_http_info(self, query : Optional[StrictStr] = None, type : Optional[StrictStr] = None, indexer_ids : Optional[List[StrictInt]] = None, categories : Optional[List[StrictInt]] = None, limit : Optional[StrictInt] = None, offset : Optional[StrictInt] = None, **kwargs):  # noqa: E501
        """list_search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_search_with_http_info(query, type, indexer_ids, categories, limit, offset, async_req=True)
        >>> result = thread.get()

        :param query:
        :type query: str
        :param type:
        :type type: str
        :param indexer_ids:
        :type indexer_ids: List[int]
        :param categories:
        :type categories: List[int]
        :param limit:
        :type limit: int
        :param offset:
        :type offset: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[ReleaseResource], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'query',
            'type',
            'indexer_ids',
            'categories',
            'limit',
            'offset'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_search" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('query') is not None:  # noqa: E501
            _query_params.append(('Query', _params['query']))
        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('Type', _params['type']))
        if _params.get('indexer_ids') is not None:  # noqa: E501
            _query_params.append(('IndexerIds', _params['indexer_ids']))
            _collection_formats['IndexerIds'] = 'multi'
        if _params.get('categories') is not None:  # noqa: E501
            _query_params.append(('Categories', _params['categories']))
            _collection_formats['Categories'] = 'multi'
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('Limit', _params['limit']))
        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('Offset', _params['offset']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['X-Api-Key', 'apikey']  # noqa: E501

        _response_types_map = {
            '200': "List[ReleaseResource]",
        }

        return self.api_client.call_api(
            '/api/v1/search', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TvSearchParam(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    Q = 'q'
    SEASON = 'season'
    EP = 'ep'
    IMDB_ID = 'imdbId'
    TVDB_ID = 'tvdbId'
    R_ID = 'rId'
    TV_MAZE_ID = 'tvMazeId'
    TRAKT_ID = 'traktId'
    TMDB_ID = 'tmdbId'
    DOUBAN_ID = 'doubanId'
    GENRE = 'genre'
    YEAR = 'year'




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from prowlarr.models.download_protocol import DownloadProtocol
from prowlarr.models.indexer_category import IndexerCategory

class ReleaseResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    guid: Optional[str]
    age: Optional[int]
    age_hours: Optional[float]
    age_minutes: Optional[float]
    size: Optional[int]
    files: Optional[int]
    grabs: Optional[int]
    indexer_id: Optional[int]
    indexer: Optional[str]
    sub_group: Optional[str]
    release_hash: Optional[str]
    title: Optional[str]
    approved: Optional[bool]
    imdb_id: Optional[int]
    publish_date: Optional[datetime]
    comment_url: Optional[str]
    download_url: Optional[str]
    info_url: Optional[str]
    poster_url: Optional[str]
    indexer_flags: Optional[List]
    categories: Optional[List]
    magnet_url: Optional[str]
    info_hash: Optional[str]
    seeders: Optional[int]
    leechers: Optional[int]
    protocol: Optional[DownloadProtocol]
    file_name: Optional[str]
    __properties = ["id", "guid", "age", "ageHours", "ageMinutes", "size", "files", "grabs", "indexerId", "indexer", "subGroup", "releaseHash", "title", "approved", "imdbId", "publishDate", "commentUrl", "downloadUrl", "infoUrl", "posterUrl", "indexerFlags", "categories", "magnetUrl", "infoHash", "seeders", "leechers", "protocol", "fileName"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ReleaseResource:
        """Create an instance of ReleaseResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "file_name",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in categories (list)
        _items = []
        if self.categories:
            for _item in self.categories:
                if _item:
                    _items.append(_item.to_dict())
            _dict['categories'] = _items
        # set to None if guid (nullable) is None
        if self.guid is None:
            _dict['guid'] = None

        # set to None if files (nullable) is None
        if self.files is None:
            _dict['files'] = None

        # set to None if grabs (nullable) is None
        if self.grabs is None:
            _dict['grabs'] = None

        # set to None if indexer (nullable) is None
        if self.indexer is None:
            _dict['indexer'] = None

        # set to None if sub_group (nullable) is None
        if self.sub_group is None:
            _dict['subGroup'] = None

        # set to None if release_hash (nullable) is None
        if self.release_hash is None:
            _dict['releaseHash'] = None

        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if comment_url (nullable) is None
        if self.comment_url is None:
            _dict['commentUrl'] = None

        # set to None if download_url (nullable) is None
        if self.download_url is None:
            _dict['downloadUrl'] = None

        # set to None if info_url (nullable) is None
        if self.info_url is None:
            _dict['infoUrl'] = None

        # set to None if poster_url (nullable) is None
        if self.poster_url is None:
            _dict['posterUrl'] = None

        # set to None if indexer_flags (nullable) is None
        if self.indexer_flags is None:
            _dict['indexerFlags'] = None

        # set to None if categories (nullable) is None
        if self.categories is None:
            _dict['categories'] = None

        # set to None if magnet_url (nullable) is None
        if self.magnet_url is None:
            _dict['magnetUrl'] = None

        # set to None if info_hash (nullable) is None
        if self.info_hash is None:
            _dict['infoHash'] = None

        # set to None if seeders (nullable) is None
        if self.seeders is None:
            _dict['seeders'] = None

        # set to None if leechers (nullable) is None
        if self.leechers is None:
            _dict['leechers'] = None

        # set to None if file_name (nullable) is None
        if self.file_name is None:
            _dict['fileName'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ReleaseResource:
        """Create an instance of ReleaseResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ReleaseResource.parse_obj(obj)

        _obj = ReleaseResource.parse_obj({
            "id": obj.get("id"),
            "guid": obj.get("guid"),
            "age": obj.get("age"),
            "age_hours": obj.get("ageHours"),
            "age_minutes": obj.get("ageMinutes"),
            "size": obj.get("size"),
            "files": obj.get("files"),
            "grabs": obj.get("grabs"),
            "indexer_id": obj.get("indexerId"),
            "indexer": obj.get("indexer"),
            "sub_group": obj.get("subGroup"),
            "release_hash": obj.get("releaseHash"),
            "title": obj.get("title"),
            "approved": obj.get("approved"),
            "imdb_id": obj.get("imdbId"),
            "publish_date": obj.get("publishDate"),
            "comment_url": obj.get("commentUrl"),
            "download_url": obj.get("downloadUrl"),
            "info_url": obj.get("infoUrl"),
            "poster_url": obj.get("posterUrl"),
            "indexer_flags": obj.get("indexerFlags"),
            "categories": [IndexerCategory.from_dict(_item) for _item in obj.get("categories")] if obj.get("categories") is not None else None,
            "magnet_url": obj.get("magnetUrl"),
            "info_hash": obj.get("infoHash"),
            "seeders": obj.get("seeders"),
            "leechers": obj.get("leechers"),
            "protocol": obj.get("protocol"),
            "file_name": obj.get("fileName")
        })
        return _obj




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuthenticationRequiredType(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    ENABLED = 'enabled'
    DISABLED_FOR_LOCAL_ADDRESSES = 'disabledForLocalAddresses'




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from prowlarr.models.book_search_param import BookSearchParam
from prowlarr.models.indexer_category import IndexerCategory
from prowlarr.models.movie_search_param import MovieSearchParam
from prowlarr.models.music_search_param import MusicSearchParam
from prowlarr.models.search_param import SearchParam
from prowlarr.models.tv_search_param import TvSearchParam

class IndexerCapabilityResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    limits_max: Optional[int]
    limits_default: Optional[int]
    categories: Optional[List]
    supports_raw_search: Optional[bool]
    search_params: Optional[List]
    tv_search_params: Optional[List]
    movie_search_params: Optional[List]
    music_search_params: Optional[List]
    book_search_params: Optional[List]
    __properties = ["id", "limitsMax", "limitsDefault", "categories", "supportsRawSearch", "searchParams", "tvSearchParams", "movieSearchParams", "musicSearchParams", "bookSearchParams"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IndexerCapabilityResource:
        """Create an instance of IndexerCapabilityResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in categories (list)
        _items = []
        if self.categories:
            for _item in self.categories:
                if _item:
                    _items.append(_item.to_dict())
            _dict['categories'] = _items
        # set to None if limits_max (nullable) is None
        if self.limits_max is None:
            _dict['limitsMax'] = None

        # set to None if limits_default (nullable) is None
        if self.limits_default is None:
            _dict['limitsDefault'] = None

        # set to None if categories (nullable) is None
        if self.categories is None:
            _dict['categories'] = None

        # set to None if search_params (nullable) is None
        if self.search_params is None:
            _dict['searchParams'] = None

        # set to None if tv_search_params (nullable) is None
        if self.tv_search_params is None:
            _dict['tvSearchParams'] = None

        # set to None if movie_search_params (nullable) is None
        if self.movie_search_params is None:
            _dict['movieSearchParams'] = None

        # set to None if music_search_params (nullable) is None
        if self.music_search_params is None:
            _dict['musicSearchParams'] = None

        # set to None if book_search_params (nullable) is None
        if self.book_search_params is None:
            _dict['bookSearchParams'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IndexerCapabilityResource:
        """Create an instance of IndexerCapabilityResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return IndexerCapabilityResource.parse_obj(obj)

        _obj = IndexerCapabilityResource.parse_obj({
            "id": obj.get("id"),
            "limits_max": obj.get("limitsMax"),
            "limits_default": obj.get("limitsDefault"),
            "categories": [IndexerCategory.from_dict(_item) for _item in obj.get("categories")] if obj.get("categories") is not None else None,
            "supports_raw_search": obj.get("supportsRawSearch"),
            "search_params": obj.get("searchParams"),
            "tv_search_params": obj.get("tvSearchParams"),
            "movie_search_params": obj.get("movieSearchParams"),
            "music_search_params": obj.get("musicSearchParams"),
            "book_search_params": obj.get("bookSearchParams")
        })
        return _obj




# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup

setup()



# coding: utf-8

# flake8: noqa

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


# import apis into api package
from prowlarr.api.api_info_api import ApiInfoApi
from prowlarr.api.app_profile_api import AppProfileApi
from prowlarr.api.application_api import ApplicationApi
from prowlarr.api.authentication_api import AuthenticationApi
from prowlarr.api.backup_api import BackupApi
from prowlarr.api.command_api import CommandApi
from prowlarr.api.custom_filter_api import CustomFilterApi
from prowlarr.api.development_config_api import DevelopmentConfigApi
from prowlarr.api.download_client_api import DownloadClientApi
from prowlarr.api.download_client_config_api import DownloadClientConfigApi
from prowlarr.api.file_system_api import FileSystemApi
from prowlarr.api.health_api import HealthApi
from prowlarr.api.history_api import HistoryApi
from prowlarr.api.host_config_api import HostConfigApi
from prowlarr.api.indexer_api import IndexerApi
from prowlarr.api.indexer_default_categories_api import IndexerDefaultCategoriesApi
from prowlarr.api.indexer_editor_api import IndexerEditorApi
from prowlarr.api.indexer_proxy_api import IndexerProxyApi
from prowlarr.api.indexer_stats_api import IndexerStatsApi
from prowlarr.api.indexer_status_api import IndexerStatusApi
from prowlarr.api.initialize_js_api import InitializeJsApi
from prowlarr.api.localization_api import LocalizationApi
from prowlarr.api.log_api import LogApi
from prowlarr.api.log_file_api import LogFileApi
from prowlarr.api.newznab_api import NewznabApi
from prowlarr.api.notification_api import NotificationApi
from prowlarr.api.ping_api import PingApi
from prowlarr.api.quality_profile_schema_api import QualityProfileSchemaApi
from prowlarr.api.search_api import SearchApi
from prowlarr.api.static_resource_api import StaticResourceApi
from prowlarr.api.system_api import SystemApi
from prowlarr.api.tag_api import TagApi
from prowlarr.api.tag_details_api import TagDetailsApi
from prowlarr.api.task_api import TaskApi
from prowlarr.api.ui_config_api import UiConfigApi
from prowlarr.api.update_api import UpdateApi
from prowlarr.api.update_log_file_api import UpdateLogFileApi
